@@ -1,5 +1,8 @@
 package Perinci::Access::HTTP::Client;
 
+our $DATE = '2015-09-06'; # DATE
+our $VERSION = '0.22'; # VERSION
+
 use 5.010001;
 use strict;
 use warnings;
@@ -11,8 +14,6 @@ use Scalar::Util qw(blessed);
 
 use parent qw(Perinci::Access::Base);
 
-our $VERSION = '0.21'; # VERSION
-
 my @logging_methods = Log::Any->logging_methods();
 
 sub new {
@@ -276,7 +277,7 @@ Perinci::Access::HTTP::Client - Riap::HTTP client
 
 =head1 VERSION
 
-This document describes version 0.21 of Perinci::Access::HTTP::Client (from Perl distribution Perinci-Access-HTTP-Client), released on 2014-10-24.
+This document describes version 0.22 of Perinci::Access::HTTP::Client (from Perl distribution Perinci-Access-HTTP-Client), released on 2015-09-06.
 
 =head1 SYNOPSIS
 
@@ -316,8 +317,6 @@ This document describes version 0.21 of Perinci::Access::HTTP::Client (from Perl
 
 This class implements L<Riap::HTTP> client.
 
-This class uses L<Log::Any> for logging.
-
 =for Pod::Coverage ^action_.+
 
 =head1 ATTRIBUTES
@@ -421,8 +420,6 @@ single instead of double slash after C<http:>):
 Since this module is using L<LWP>, you can set environment variable
 C<PERL_LWP_SSL_VERIFY_HOSTNAME> to 0. See LWP for more details.
 
-=head1 TODO
-
 =head1 SEE ALSO
 
 L<Perinci::Access::HTTP::Server>
@@ -435,7 +432,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Perinci-Ac
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-Perinci-Access-HTTP-Client>.
+Source repository is at L<https://github.com/sharyanto/perl-Perinci-Access-HTTP-Client>.
 
 =head1 BUGS
 
@@ -451,7 +448,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by perlancar@cpan.org.
+This software is copyright (c) 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
